##  Configuring Mappings
On the Mappings tab of the ServiceNow configuration page, you can configure mappings for fact sheets and fact sheet relations between SAP LeanIX and ServiceNow. For details, refer to:
  * [Fact Sheet Mapping Between ServiceNow and SAP LeanIX](https://help.sap.com/docs/leanix/ea/fact-sheet-mapping-between-servicenow-and-sap-leanix?locale=en-US&state=PRODUCTION&version=CLOUD "Configure mappings between specific fields in SAP LeanIX fact sheets and ServiceNow tables.")
  * [Relation Mapping Between ServiceNow and SAP LeanIX](https://help.sap.com/docs/leanix/ea/relation-mapping-between-servicenow-and-sap-leanix?locale=en-US&state=PRODUCTION&version=CLOUD "Map relations between records in ServiceNow and fact sheets in SAP LeanIX.")
